@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
@@ -27,14 +28,15 @@ class Exceptions:
 
 class WorkMailMessageFlowClient:
     """
-    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -45,10 +47,10 @@ class WorkMailMessageFlowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
         """
 
     def get_raw_message_content(self, messageId: str) -> GetRawMessageContentResponseTypeDef:
         """
-        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
         """
